##  Prerequisites
Prepare the following:
  * A YAML manifest file
  * A relevant Python script


To learn how to create a YAML file and a Python script, see [Microservice Discovery in Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline?locale=en-US&state=PRODUCTION&version=CLOUD "Set up microservice discovery using a manifest file in your repository. This method, known as configuration-as-code, enables you to automatically discover microservices and update corresponding fact sheets in SAP LeanIX.").
To view the manifest file and schema, refer to [Manifest File and Schema](https://help.sap.com/docs/leanix/ea/manifest-file-and-schema?locale=en-US&state=PRODUCTION&version=CLOUD "Manifest file for microservice discovery and the manifest schema.").
